@@ -1,4 +1,4 @@
-## Copyright (c) 2012, 2013 Aldebaran Robotics. All rights reserved.
+## Copyright (c) 2012-2014 Aldebaran Robotics. All rights reserved.
 ## Use of this source code is governed by a BSD-style license that can be
 ## found in the COPYING file.
 
@@ -22,8 +22,11 @@ def log_parser(parser):
         help="Add timestamps before each log message")
     group.add_argument("--color", choices=["always", "never", "auto"],
         help="Colorize output, defaults to 'auto'")
+    group.add_argument("--title", choices=["always", "never", "auto"],
+        help="Update terminal title, defaults to 'auto'")
 
     parser.set_defaults(verbose=False, quiet=False, color="auto")
+    parser.set_defaults(verbose=False, quiet=False, title="auto")
 
 def default_parser(parser):
     """Parser settings for every action."""
